# ==================================================================
# Plugins::Community::Tables - Auto Generated Install Module
#
#   Plugins::Community::Tables
#   Author  : Jonathan Gamble
#   Version : 3.0
#   Updated : Mon Oct 15 22:20:43 2007
#
# ==================================================================
#

package Plugins::Community::Tables;
# ==================================================================
    use strict;
    use vars  qw/$VERSION $DEBUG $NAME $META $FILES $PATH/;
    use GT::Base;
    use GT::Plugins qw/STOP CONTINUE/;
    use Community qw/$CFG $IN $DB/;

    $VERSION = '3.0';
    $DEBUG   = 0;
    $NAME    = 'Tables';
# Inhert from base class for debug and error methods
    @Plugins::Community::Tables::ISA = qw(GT::Base);

    $META = {
    'author' => 'Jonathan Gamble',
    'description' => 'This creates a mysql administration using GT\'s definitions.',
    'license' => 'Freeware',
    'prog_ver' => '3',
    'url' => 'http://www.gossamer-threads.com/perl/gforum/gforum.cgi?post=294026',
    'version' => '3.0'
};
    $PATH = "$CFG->{path_private}/templates/$CFG->{system_template_set}";

	$FILES = {
		'admin_tables_menu.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_table.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_create_form.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_drop_form.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},

		'admin_tables_adv.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_adv_create.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_adv_fields.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_adv_keys.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		},
		'admin_tables_adv_table.html' => {
			'path' => $PATH,
			'chmod' => '0644'
		}
	};


sub pre_install {
# -----------------------------------------------------------------------------
# This function displays an HTML formatted message that will display any
# instructions/information to the user before they install the plugin.
#
    my $inst_msg = 'This will install the Tables Editor.';

    return $inst_msg;
}

sub pre_uninstall {
# -----------------------------------------------------------------------------
# This function displays an HTML formatted message that will display any
# instructions/information to the user before they remove the plugin.
#
    my $uninst_msg = 'This will uninstall the Tables Editor.';

    return $uninst_msg;
}

sub install {
# -----------------------------------------------------------------------------
# This function does the actual installation.  Its first argument is a plugin
# manager which you can use to register hooks, install files, add menu options,
# etc.  The second argument is a GT::Tar object which you can use to access any
# files in your plugin module.
#
# You should return an HTML formatted string that will be displayed to the
# user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::Community::Tables::error
#
    my ($mgr, $tar) = @_;
    
    $mgr->install_options('Tables', [['Path', $CFG->{path_private}. '/defs', 'This is the path to your definitions files!', 'TEXT', [], [], '']]);
    $mgr->install_menu('Tables', [['Tables SQL', 'community.cgi?do=admin_plugin&plugin=Tables&func=tables_menu']]);
    ;

# Silence warnings
    $GT::Tar::error ||= '';
    
# The following section will unarchive attached files into the proper location.
	my $file;
	foreach (keys %{$FILES}) {
		$file = $tar->get_file($_);
		$file->name("$FILES->{$_}->{path}/$_");
		$file->write or return Plugins::Community::MyPage->error("Unable to extract file '$FILES->{$_}->{path}/$_' : $GT::Tar::error", 'WARN');	
	    chmod ($FILES->{$_}->{chmod}, $_);
	}
# Copying tables.cgi to the cgi-bin directory.
    $file = $tar->get_file('tables.cgi');
# Get the entire code as a string.
    my $code = $file->body_as_string;
# Replace the path to perl with the users perl.
    $code =~ s/^#!(.*)/#!$CFG->{path_perl}/;
# Replace the use lib with the users admin directory.
    $code =~ s/use lib '[^']+'/use lib '$CFG->{path_private}\/lib'/;
    $code =~ s,Community::init\('[^']+'\),Community::init('$CFG->{path_private}'),;
# Put the new contents in the file
    $file->body ($code);
    $file->name("$CFG->{path_cgi}/tables.cgi");
    $file->write or return Plugins::Community::Tables->error("Unable to extract file '$CFG->{path_cgi}/tables.cgi': $GT::Tar::error", 'WARN');
# Set permissions for tables.cgi
    chmod (0755, $file->name);

    return "The plugin has been successfully installed!";
}

sub uninstall {
# -----------------------------------------------------------------------------
# This function removes the plugin.  Its first argument is also a plugin
# manager which you can use to register hooks, install files, add menu options,
# etc. You should return an HTML formatted string that will be displayed to the
# user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::Community::Tables::error
#
    my $mgr = shift;

    my $template_set = $CFG->{system_template_set};
    
    $mgr->uninstall_options('Tables', [['Path', '/home/user/dada', 'This is the path to your definitions files!', 'TEXT', [], [], '']]);
    $mgr->uninstall_menu('Tables', [['Tables SQL', 'community.cgi?do=admin_plugin&plugin=Tables&func=tables_menu']]);
    
# Delete the required files

	foreach (keys %{$FILES}) {
    	unlink ("$FILES->{$_}->{path}/$_") or return Plugins::Community::Tables->error("Unable to delete file '$FILES->{$_}->{path}/$_': $GT::Tar::error", 'WARN');
	}
	unlink ("$CFG->{path_cgi}/tables.cgi") or return Plugins::Community::Tables->error("Unable to delete file '$CFG->{path_cgi}/tables.cgi': $GT::Tar::error", 'WARN');   
   
	return "The plugin has been successfully removed!";
}

1;